==> aroundme_0_6_6.tar.tgz: aroundme_0_6_6/aroundme/language/1/barnraiser_01/chl_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


//HEADER
$lang['hdr_channel'] = 							"channel";


// FORM
$lang['form_label_title'] = 					"Title";
$lang['form_label_synopsis'] = 					"Synopsis";
$lang['form_lable_url'] = 						"URL";


// BODY
$lang['txt_header_1'] = 						"1. Channel overview";
$lang['txt_overview_intro'] = 					"You can add a channel to this community. A channel is a transmission between two or more points. On a web site it is typically an incoming feed of information coming from another web site. These channels can contain text, pictures and BitTorrent peer to peer shared files such as videos and mp3s.";
$lang['txt_header_2'] = 						"2. Publishing";
$lang['txt_publishing_intro'] = 				"Choose where you would like this channel published to.";
$lang['txt_header_3'] = 						"3. Save";
$lang['txt_save_intro'] = 						"Save your work. You will take you to the details page.";
$lang['txt_publish_node_help'] =				"Item will be submitted to Splash editor and can be viewed by any member of this community.";
$lang['txt_publish_node_help'] =				"submit to 'Community' editor for inclusion in the featured page";
$lang['txt_publish_auto_node_help'] = 			"include in the 'Community' featured page";

?>

==> aroundme_0_6_9.tar.tgz: aroundme_0_6_9/aroundme/language/1/barnraiser_01/chl_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


//HEADER
$lang['hdr_channel'] = 							"channel";


// FORM
$lang['form_label_title'] = 					"Title";
$lang['form_label_synopsis'] = 					"Synopsis";
$lang['form_label_url'] = 						"URL";
$lang['form_label_language'] = 					"language";
$lang['form_label_type'] = 						"type";


// BODY
$lang['txt_header_1'] = 						"1. Channel overview";
$lang['txt_overview_intro'] = 					"You can add a channel to this community. A channel is a transmission between two or more points. On a web site it is typically an incoming feed of information coming from another web site. These channels can contain text, pictures and BitTorrent peer to peer shared files such as videos and mp3s.";
$lang['txt_header_2'] = 						"2. Publishing";
$lang['txt_publishing_intro'] = 				"Choose where you would like this channel published to.";
$lang['txt_header_3'] = 						"3. Save";
$lang['txt_save_intro'] = 						"Save your work. You will take you to the details page.";
$lang['txt_publish_node_help'] =				"Item will be submitted to Splash editor and can be viewed by any member of this community.";
$lang['txt_publish_node_help'] =				"share this channel with the 'community'";
$lang['txt_publish_auto_node_help'] = 			"include in the 'Community' featured page";
$lang['txt_none'] = 							"none";

?>
